Struct kas_text::fonts::FaceData

source ·
pub struct FaceData<'a> { /* private fields */ }
Provides access to font data

Each valid FaceId is an index to a loaded font face. Since faces are never unloaded or replaced, FaceId::get is a valid index into these arrays for any valid FaceId.

Implementations

Number of available font faces

Access font path and face index

Note: use FaceData::get_data to access the font file data, already loaded into memory.

Access font data and face index