FamilySelector

Struct FamilySelector 

pub struct FamilySelector(/* private fields */);
A (cached) family selector

This may be constructed directly for some generic families; for other families use Resolver::select_families.

This is a small, Copy type (a newtype over u64).

Implementations

Source

impl FamilySelector

pub const SERIF: FamilySelector

Glyphs have finishing strokes, flared or tapering ends, or have actual serifed endings.

pub const SANS_SERIF: FamilySelector

Glyphs have stroke endings that are plain.

pub const MONOSPACE: FamilySelector

All glyphs have the same fixed width.

pub const CURSIVE: FamilySelector

Glyphs in cursive fonts generally have either joining strokes or other cursive characteristics beyond those of italic typefaces. The glyphs are partially or completely connected, and the result looks more like handwritten pen or brush writing than printed letter work.

pub const SYSTEM_UI: FamilySelector

Glyphs are taken from the default user interface font on a given platform.

pub const EMOJI: FamilySelector

Fonts that are specifically designed to render emoji.

pub const MATH: FamilySelector

This is for the particular stylistic concerns of representing mathematics: superscript and subscript, brackets that cross several lines, nesting expressions, and double struck glyphs with distinct meanings.

pub const FANG_SONG: FamilySelector

A particular style of Chinese characters that are between serif-style Song and cursive-style Kai forms. This style is often used for government documents.

pub fn as_generic(self) -> Option<GenericFamily>

Convert to a GenericFamily where possible

pub fn generic_name(self) -> Option<&'static str>

Get a CSS-style generic family name where possible

pub fn parse_generic(name: &str) -> Option<Self>

Parse a CSS-style family descriptor