pub struct FontSelector<'a> { /* private fields */ }
A font face selection tool

This tool selects a font according to the given criteria from available system fonts. Selection criteria are based on CSS.

Implementations

Synonym for default

Without further parametrization, this will select a generic sans-serif font which should be suitable for most uses.

Set self to rhs

This may save a reallocation over direct assignment.

Set family name(s)

This supports generic names serif, sans-serif, monospace, cursive and fantasy. It also allows specific family names, though does not currently define compatibility aliases for these (e.g. arial will match the Arial font if found, but should not currently be expected to resolve other, compatible, fonts).

If multiple names are passed, the first to successfully resolve a font is used. Glyph-level fallback (missing glyph substitution) is not currently supported.

If an empty vector is passed, the default “sans-serif” font is used.

Set style

Set weight

Set stretch