FontWeight

Struct FontWeight 

pub struct FontWeight(/* private fields */);
Visual weight class of a font, typically on a scale from 1 to 1000.

The default value is FontWeight::NORMAL or 400.

In variable fonts, this can be controlled with the wght axis. This is a u16 so that it can represent the same range of values as the wght axis.

See https://fonts.google.com/knowledge/glossary/weight

In CSS, this corresponds to the font-weight property.

Implementations

Source

impl FontWeight

pub const THIN: Self

Weight value of 100.

pub const EXTRA_LIGHT: Self

Weight value of 200.

pub const LIGHT: Self

Weight value of 300.

pub const SEMI_LIGHT: Self

Weight value of 350.

pub const NORMAL: Self

Weight value of 400. This is the default value.

pub const MEDIUM: Self

Weight value of 500.

pub const SEMI_BOLD: Self

Weight value of 600.

pub const BOLD: Self

Weight value of 700.

pub const EXTRA_BOLD: Self

Weight value of 800.

pub const BLACK: Self

Weight value of 900.

pub const EXTRA_BLACK: Self

Weight value of 950.

Source

impl FontWeight

pub fn new(weight: u16) -> Self

Creates a new weight attribute with the given value.

pub fn value(self) -> u16

Returns the underlying weight value.

pub fn parse(s: &str) -> Option<Self>

Parses a CSS style font weight attribute.

This function accepts only normal, bold and numeric values.

Examples
assert_eq!(FontWeight::parse("normal"), Some(FontWeight::NORMAL));
assert_eq!(FontWeight::parse("bold"), Some(FontWeight::BOLD));
assert_eq!(FontWeight::parse("850"), Some(FontWeight::new(850)));
assert_eq!(FontWeight::parse("invalid"), None);