FontWidth

Struct FontWidth 

pub struct FontWidth(/* private fields */);
Visual width of a font– a relative change from the normal aspect ratio, typically in the 50% - 200% range.

The default value is FontWidth::NORMAL.

In variable fonts, this can be controlled with the wdth axis.

In Open Type, the u16 usWidthClass field has 9 values, from 1-9, which doesn’t allow for the wide range of values possible with variable fonts.

See https://fonts.google.com/knowledge/glossary/width

In CSS, this corresponds to the font-width property, formerly known as font-stretch.

Implementations

Source

impl FontWidth

pub const ULTRA_CONDENSED: Self

Width that is 50% of normal.

pub const EXTRA_CONDENSED: Self

Width that is 62.5% of normal.

pub const CONDENSED: Self

Width that is 75% of normal.

pub const SEMI_CONDENSED: Self

Width that is 87.5% of normal.

pub const NORMAL: Self

Width that is 100% of normal. This is the default value.

pub const SEMI_EXPANDED: Self

Width that is 112.5% of normal.

pub const EXPANDED: Self

Width that is 125% of normal.

pub const EXTRA_EXPANDED: Self

Width that is 150% of normal.

pub const ULTRA_EXPANDED: Self

Width that is 200% of normal.

Source

impl FontWidth

pub fn from_ratio(ratio: f32) -> Self

Creates a new width attribute with the given ratio.

Panics if the ratio is not between 0 and 255.996.

This can also be created from a percentage.

Example
assert_eq!(FontWidth::from_ratio(1.5), FontWidth::EXTRA_EXPANDED);
pub fn from_percentage(percentage: f32) -> Self

Creates a width attribute from a percentage.

Panics if the percentage is not between 0% and 25599.6%.

This can also be created from a ratio.

Example
assert_eq!(FontWidth::from_percentage(87.5), FontWidth::SEMI_CONDENSED);
pub fn ratio(self) -> f32

Returns the width attribute as a ratio.

This is a linear scaling factor with 1.0 being “normal” width.

Example
assert_eq!(FontWidth::NORMAL.ratio(), 1.0);
pub fn percentage(self) -> f32

Returns the width attribute as a percentage value.

This is generally the value associated with the wdth axis.

pub fn is_normal(self) -> bool

Returns true if the width is normal.

pub fn is_condensed(self) -> bool

Returns true if the width is condensed (less than normal).

pub fn is_expanded(self) -> bool

Returns true if the width is expanded (greater than normal).

pub fn parse(s: &str) -> Option<Self>

Parses the width from a CSS style keyword or a percentage value.

Examples
assert_eq!(FontWidth::parse("semi-condensed"), Some(FontWidth::SEMI_CONDENSED));
assert_eq!(FontWidth::parse("80%"), Some(FontWidth::from_percentage(80.0)));
assert_eq!(FontWidth::parse("wideload"), None);