Struct kas_text::fonts::ScaledFaceRef
source · pub struct ScaledFaceRef(_, _);Expand description
Handle to a loaded font face
Implementations
sourceimpl ScaledFaceRef
impl ScaledFaceRef
sourcepub fn h_advance(&self, id: GlyphId) -> f32
pub fn h_advance(&self, id: GlyphId) -> f32
Horizontal advancement after this glyph, without shaping or kerning
sourcepub fn h_side_bearing(&self, id: GlyphId) -> f32
pub fn h_side_bearing(&self, id: GlyphId) -> f32
Horizontal side bearing
If unspecified by the font this resolves to 0.
sourcepub fn underline_metrics(&self) -> Option<LineMetrics>
pub fn underline_metrics(&self) -> Option<LineMetrics>
Metrics for underline
sourcepub fn strikethrough_metrics(&self) -> Option<LineMetrics>
pub fn strikethrough_metrics(&self) -> Option<LineMetrics>
Metrics for strike-through