Font formatting token
Fields
start: u32Index in text at which formatting becomes active
(Note that we use u32 not usize since it can be assumed text length
will never exceed u32::MAX.)
font_id: FontIdFont identifier
dpem: f32Font size, in dots-per-em (pixel width of an ‘M’)
This may be calculated from point size as pt_size * dpp, where dpp
is the number of pixels per point (see crate::fonts documentation).