MarkerPos

Struct MarkerPos 

pub struct MarkerPos {
    pub pos: Vec2,
    pub ascent: f32,
    pub descent: f32,
    /* private fields */
}
Used to return the position of a glyph with associated metrics

Fields

pos: Vec2

(x, y) coordinate of glyph

ascent: f32

Ascent (subtract from y to get top)

descent: f32

Descent (subtract from y to get bottom)

Implementations

Source

impl MarkerPos

pub fn embedding_level(&self) -> u8

Returns the embedding level

According to Unicode Technical Report #9, the embedding level is guaranteed to be between 0 and 125 (inclusive), with a default level of zero and where odd levels are right-to-left.

pub fn is_ltr(&self) -> bool

Returns true if the cursor is left-to-right

pub fn is_rtl(&self) -> bool

Returns true if the cursor is right-to-left