pub struct FontWeight(/* private fields */);Expand description
Visual weight class of a font, typically on a scale from 1 to 1000.
The default value is FontWeight::NORMAL or 400.
In variable fonts, this can be controlled with the wght axis. This
is a u16 so that it can represent the same range of values as the
wght axis.
See https://fonts.google.com/knowledge/glossary/weight
In CSS, this corresponds to the font-weight property.
Implementations
Sourceimpl FontWeight
impl FontWeight
Sourcepub const EXTRA_LIGHT: Self
pub const EXTRA_LIGHT: Self
Weight value of 200.
Sourcepub const SEMI_LIGHT: Self
pub const SEMI_LIGHT: Self
Weight value of 350.
Sourcepub const EXTRA_BOLD: Self
pub const EXTRA_BOLD: Self
Weight value of 800.
Sourcepub const EXTRA_BLACK: Self
pub const EXTRA_BLACK: Self
Weight value of 950.
Sourceimpl FontWeight
impl FontWeight
Sourcepub fn parse(s: &str) -> Option<Self>
pub fn parse(s: &str) -> Option<Self>
Parses a CSS style font weight attribute.
This function accepts only normal, bold and numeric values.
Examples
assert_eq!(FontWeight::parse("normal"), Some(FontWeight::NORMAL));
assert_eq!(FontWeight::parse("bold"), Some(FontWeight::BOLD));
assert_eq!(FontWeight::parse("850"), Some(FontWeight::new(850)));
assert_eq!(FontWeight::parse("invalid"), None);Trait Implementations
Sourceimpl Clone for FontWeight
impl Clone for FontWeight
Sourcefn clone(&self) -> FontWeight
fn clone(&self) -> FontWeight
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FontWeight
Sourceimpl Debug for FontWeight
impl Debug for FontWeight
Sourceimpl Default for FontWeight
impl Default for FontWeight
Sourceimpl<'de> Deserialize<'de> for FontWeight
impl<'de> Deserialize<'de> for FontWeight
Sourcefn deserialize<D: Deserializer<'de>>(de: D) -> Result<FontWeight, D::Error>
fn deserialize<D: Deserializer<'de>>(de: D) -> Result<FontWeight, D::Error>
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for FontWeight
impl Display for FontWeight
impl Eq for FontWeight
Sourceimpl From<FontWeight> for FontWeight
impl From<FontWeight> for FontWeight
Sourcefn from(weight: FontWeight) -> Self
fn from(weight: FontWeight) -> Self
Converts to this type from the input type.
Sourceimpl Hash for FontWeight
impl Hash for FontWeight
Sourceimpl Ord for FontWeight
impl Ord for FontWeight
Sourcefn cmp(&self, other: &FontWeight) -> Ordering
fn cmp(&self, other: &FontWeight) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FontWeight
impl PartialEq for FontWeight
Sourcefn eq(&self, other: &FontWeight) -> bool
fn eq(&self, other: &FontWeight) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FontWeight
impl PartialOrd for FontWeight
Sourceimpl Serialize for FontWeight
impl Serialize for FontWeight
impl StructuralPartialEq for FontWeight